@@ -68,7 +68,7 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
                 return code, code_dict.get(str(code)), ""
             if isinstance(file, bytes):
                 file = base64.b64decode(file)
-            if isinstance(file, Iterable):
+            if isinstance(file, Iterable) and not isinstance(file, bytes):
                 f_file = b''
                 for f in file:
                     f_file += f
